@@ -201,7 +201,7 @@ impl<'a> Btf<'a> {
                     btf::BtfIntEncoding::Signed => format!("i{}", width),
                     btf::BtfIntEncoding::Bool => {
                         assert!(t.bits as usize == (std::mem::size_of::<bool>() * 8));
-                        format!("bool")
+                        "bool".to_string()
                     }
                     btf::BtfIntEncoding::Char | btf::BtfIntEncoding::None => format!("u{}", width),
                 }
@@ -474,11 +474,14 @@ impl<'a> Btf<'a> {
                         // Set `offset` to end of current var
                         offset = ((member.bit_offset / 8) + self.size_of(field_ty_id)?) as usize;
 
-                        agg_content.push(format!(
-                            r#"    pub {field_name}: {field_ty_str},"#,
-                            field_name = member.name,
-                            field_ty_str = self.type_declaration(field_ty_id)?,
-                        ));
+                        let field_ty_str = self.type_declaration(field_ty_id)?;
+                        let field_name = if !member.name.is_empty() {
+                            member.name.to_string()
+                        } else {
+                            field_ty_str.clone()
+                        };
+
+                        agg_content.push(format!(r#"    pub {}: {},"#, field_name, field_ty_str));
                     }
 
                     if !gen_impl_default && t.is_struct {
@@ -604,6 +607,11 @@ impl<'a> Btf<'a> {
                     for datasec_var in &t.vars {
                         let var = match self.type_by_id(datasec_var.type_id)? {
                             BtfType::Var(v) => {
+                                if v.linkage == BtfVarLinkage::Static {
+                                    // do not output Static Var
+                                    continue;
+                                }
+
                                 if let Some(next_ty_id) = next_type(v.type_id)? {
                                     dependent_types.push(next_ty_id);
                                 }
